@@ -21,7 +21,7 @@ import pandas as pd
 import colorama
 import numpy as np
 import serial
-import visa
+import pyvisa as visa
 from pyvisa.constants import StatusCode
 
 # local package imports
@@ -175,7 +175,10 @@ class SCPI(object):
         for cmd in cmd_list:
             self._cmds[cmd.name] = cmd
         self._write = comm_handle.write
-        self._ask = comm_handle.query
+        try:
+            self._ask = comm_handle.query
+        except:
+            self._ask = comm_handle.ask  #pyserial
         self.unconnected = unconnected
 
         # get the vendor ID, which often includes firmware revision and other useful info.
@@ -757,6 +760,7 @@ class Serial(object):
             parity=kwargs.get('parity', serial.PARITY_NONE),
             bytesize=kwargs.get('bytesize', serial.EIGHTBITS))
         self.terminator = kwargs.get('terminator', ' \n')
+        self.eol = kwargs.get('eol', b'\r')
         self.open()
 
         # some instruments need an initialization write,
@@ -793,14 +797,14 @@ class Serial(object):
 
     # https://stackoverflow.com/questions/16470903/pyserial-2-6-specify-end-of-line-in-readline
     def _readline(self):
-        eol = b'\r'
-        leneol = len(eol)
+        #eol = b'\r'
+        leneol = len(self.eol)
         line = bytearray()
         while True:
             c = self.ser.read(1)
             if c:
                 line += c
-                if line[-leneol:] == eol:
+                if line[-leneol:] == self.eol:
                     break
             else:
                 break
